@@ -1,6 +1,3 @@
 def cube():
     n=int(input("Enter the Number!!!!!\n"))
     print("The square of {} is {}".format(n,n**3))
-
-if __name__=="__main__":
-    cube()
\ No newline at end of file
