@@ -1,6 +1,3 @@
 def square():
     n=int(input("Enter the Number!!!!!\n"))
     print("The square of {} is {}".format(n,n*n))
-
-if __name__=="__main__":
-    square()
\ No newline at end of file
